@@ -24,11 +24,11 @@ class faker():
             return date
 
 if __name__ == '__main__':
-    host = '192.168.84.26'
-    key1 = 's_id'
-    port = 30006
-    user = 'root'
-    password = 'eisoo.com'
-    database = 'AnyRobot'
-    date1 = faker(host,port,user,password,database).route(key1)
+    host = ''
+    key = ''
+    port = 3306
+    user = ''
+    password = ''
+    database = ''
+    date1 = faker(host,port,user,password,database).route(key)
     print(date1)
\ No newline at end of file
